{% load i18n %}

{% block fields_help %}
    <div class="bg-blue-50 mb-4 text-blue-500 px-3 py-3 rounded-md text-sm dark:bg-blue-500/20 dark:border-blue-500/10">
        {% if import_or_export == "export" %}
            {% trans "This exporter will export the following fields: " %}
        {% elif import_or_export == "import" %}
            {% trans "This importer will import the following fields: " %}
        {% endif %}

        {% if fields_list|length <= 1 %}
            <code class="font-medium">
                {{ fields_list.0.1|join:", " }}
            </code>
        {% else %}
            <dl>
                {% for resource, fields in fields_list %}
                    <dt>{{ resource }}</dt>
                    <dd><code>{{ fields|join:", " }}</code></dd>
                {% endfor %}
            </dl>
        {% endif %}
    </div>
{% endblock %}
