{% extends "admin/object_history.html" %}

{% load  i18n %}

{% block content %}
    {% if not revert_disabled %}
        <p class="px-3 py-3 rounded-md text-sm last:mb-8 er-amber-600/10 bg-blue-50 mb-8 text-blue-500 dark:bg-blue-500/20 dark:border-blue-500/10">
            {% blocktrans %}Choose a date from the list below to revert to a previous version of this object.{% endblocktrans %}
        </p>
    {% endif %}

    {% if historical_records %}
        {% include object_history_list_template %}
    {% else %}
        <p class="mb-3 px-3 py-3 rounded-md text-sm last:mb-8 bg-amber-100 text-amber-600 dark:bg-amber-600/20 dark:border-amber-600/10">
            {% trans "This object doesn't have a change history." %}
        </p>
    {% endif %}
{% endblock %}
