<div class="flex group mb-6 flex-col last:mb-4">
    <label class="block font-medium mb-2 text-gray-900 text-sm dark:text-gray-200">
        {{ title }}
    </label>

    {% include "unfold/helpers/field_readonly_value.html" %}
</div>
