{% load unfold %}

<fieldset class="module{% if fieldset.classes %} {{ fieldset.classes }}{% endif %}">
    {% if fieldset.name and "tab" not in fieldset.classes %}
        <h2 class="bg-gray-100 border border-transparent font-semibold mb-6 px-4 py-3 rounded-md text-gray-700 text-sm lg:-mx-4 dark:bg-white/[.02] dark:border dark:border-gray-800 dark:text-gray-200">
            {{ fieldset.name }}
        </h2>
    {% endif %}

    {% if fieldset.description %}
        <div class="leading-relaxed mb-4 max-w-4xl text-sm">
            {{ fieldset.description|safe }}
        </div>
    {% endif %}

    <div class="aligned {% if stacked %}mb-5{% else %}border border-gray-200 mb-8 rounded-md pt-3 px-3 shadow-sm dark:border-gray-800{% endif %}">
        {% for line in fieldset %}
            {% include "unfold/helpers/fieldset_row.html" %}
        {% endfor %}
    </div>
</fieldset>
