<div class="relative w-full{% if class %} {{ class }}{% endif %}">
  <canvas class="chart" {% if options %}data-options="{{ options }}"{% endif %} data-type="line" data-value="{{ data }}" {% if width %}width="{{ width }}"{% endif %} {% if height %}height="{{ height }}"{% endif %}></canvas>
</div>
